'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var assign = require("object-assign");
var inferMediaFromCSSFilename = function (filename) {
    var matches = filename.match(/\bmedia_([A-Z0-9=]*)/i);
    if (matches) {
        // Node 5.10+
        if (typeof Buffer.from === 'function') {
            return Buffer.from(matches[1], 'base64');
        }
        // older Node versions
        return new Buffer(matches[1], 'base64');
    }
    return false;
};
/**
 * Allows you to modify the `rel` and `title` attribute on <link> elements injected by HTML Webpack Plugin.
 * This can be used to specify some stylesheets as alternate stylesheets for accessibility or theming
 * purposes.
 */
var LinkRelHTMLWebpackPlugin = /** @class */ (function () {
    function LinkRelHTMLWebpackPlugin(options) {
        this.options = options;
    }
    LinkRelHTMLWebpackPlugin.prototype.isStylesheetLink = function (def) {
        return def.tagName === 'link' && def.attributes.rel === 'stylesheet';
    };
    LinkRelHTMLWebpackPlugin.prototype.selectFileOptions = function (href) {
        return this.options.files.filter(function (x) {
            if (typeof x.file === 'string')
                return x.file === href;
            else if (x.file instanceof RegExp)
                return x.file.test(href);
            return false;
        })[0];
    };
    LinkRelHTMLWebpackPlugin.prototype.modifyRelAttribute = function (definition) {
        if (!this.isStylesheetLink(definition) || !definition.attributes.href)
            return definition;
        var options = this.selectFileOptions(definition.attributes.href);
        if (!options)
            return definition;
        var attrs = {};
        if (options.rel)
            attrs.rel = options.rel;
        if (options.title)
            attrs.title = options.title;
        return assign({}, definition, {
            attributes: assign({}, definition.attributes, attrs),
        });
    };
    LinkRelHTMLWebpackPlugin.prototype.apply = function (compiler) {
        var _this = this;
        // Hook into the html-webpack-plugin processing
        compiler.plugin('compilation', function (compilation) {
            compilation.plugin('html-webpack-plugin-alter-asset-tags', function (htmlPluginData, callback) {
                callback(null, assign({}, htmlPluginData, {
                    body: htmlPluginData.body.map(function (x) { return _this.modifyRelAttribute(x); }),
                    head: htmlPluginData.head.map(function (x) { return _this.modifyRelAttribute(x); }),
                }));
            });
        });
    };
    return LinkRelHTMLWebpackPlugin;
}());
exports.LinkRelHTMLWebpackPlugin = LinkRelHTMLWebpackPlugin;
exports.default = LinkRelHTMLWebpackPlugin;
//# sourceMappingURL=index.js.map